
using System;
using System.IO;
using System.Xml;

namespace EvaPosUtil
{
    /// <summary>
    ///  Clase Utilistarios para operaciones sobre mensajes.
    /// </summary>
    public class Util
    {
        /// <summary>
        ///  Utilitario para convertir en string contenido XML de objeto XmlNode.
        /// </summary>
        public static string ContenidoXmlComoString(XmlNode docXml)
        {
            XmlWriterSettings settings = new XmlWriterSettings();
            settings.Indent = true;
            settings.OmitXmlDeclaration = true;
            settings.NewLineOnAttributes = true;
            using (var stringWriter = new StringWriter())
            using (var xmlTextWriter = XmlWriter.Create(stringWriter, settings))
            {
                docXml.WriteTo(xmlTextWriter);
                xmlTextWriter.Flush();
                return stringWriter.GetStringBuilder().ToString();
            }
        }


        /// <summary>
        ///  Lee valor int de entidad XML indicada por xpath..
        /// </summary>
        public static int LeeIntEnNodo(XmlNode nodo, string xpath)
        {
            int valor = 0;
            XmlNode? xnodo = nodo.SelectSingleNode(xpath);
            if (xnodo == null)
                throw new Exception($"Nodo <{nodo.Name}> no contiene a <{xpath}>.");
            string? xvalor = xnodo.InnerText;
            if (xvalor == null)
                throw new Exception($"Nodo <{xpath}> con contenido nulo.");
            try
            {
                valor = int.Parse(xvalor);
            }
            catch (Exception e)
            {
                throw new Exception($"Error '{e.Message}' convirtiendo valor <{xvalor}> de <{xpath}> en entero.");
            }
            return valor;
        }

        /// <summary>
        ///  Lee valor long de entidad XML indicada por xpath..
        /// </summary>
        public static long LeeLongEnNodo(XmlNode nodo,string xpath)
        {
            long valor = 0;
            XmlNode? xnodo = nodo.SelectSingleNode(xpath);
            if (xnodo == null)
                throw new Exception($"Nodo <{nodo.Name}> no contiene a <{xpath}>.");
            string? xvalor = xnodo.InnerText;
            if (xvalor == null)
                throw new Exception($"Nodo <{xpath}> con contenido nulo.");
            try
            {
                valor = long.Parse(xvalor);
            }
            catch (Exception e)
            {
                throw new Exception($"Error '{e.Message}' convirtiendo valor <{xvalor}> de <{xpath}> en entero.");
            }
            return valor;
        }


        /// <summary>
        ///  Lee valor bool de entidad XML indicada por xpath.
        /// </summary>
        public static bool LeeBoolEnNodo(XmlNode nodo, string xpath)
        {
            bool valor = false;
            XmlNode? xnodo = nodo.SelectSingleNode(xpath);
            if (xnodo == null)
                throw new Exception($"Nodo '{nodo.Name}' no contiene a '{xpath}'.");
            string? xvalor = xnodo.InnerText;
            if (xvalor == null)
                throw new Exception($"Nodo '{xpath}' con contenido nulo.");
            else if (xvalor.ToLower() == "false")
                valor = false;
            else if (xvalor.ToLower() == "true")
                valor = true;
            else
                throw new Exception($"Valor '{xvalor}' de '{xpath}' no se puede convertir a Boolean.");
            return valor;
        }

        /// <summary>
        ///  Lee valor string de entidad XML indicada por xpath.
        /// </summary>
        public static string LeeStringEnNodo(XmlNode nodo, string xpath)
        {
            XmlNode? xnode = nodo.SelectSingleNode(xpath);
            if (xnode == null)
                throw new Exception($"Nodo '{nodo.Name}' no contiene a '{xpath}'.");
            string? valor = xnode.InnerText;
            if (valor == null)
                throw new Exception($"Nodo '{xpath}' con contenido nulo.");
            return valor;
        }
    }
}